#include <iostream>
#include <cstdio>
#include <cmath>
#include <cstring>
using namespace std;

FILE *fin, *fans;

const int    MAX_N = 32;
const double eps   = 2e-6;

struct point {
	double x, y;
	point () {}
	point (double _x, double _y) : x(_x), y(_y) {}
};

int n, s;
double L[MAX_N];
point A[MAX_N];

point ans[MAX_N];

char* input (char *fileIn, char *fileAns)
{
	fin  = fopen (fileIn, "r");
	fans = fopen (fileAns, "r");

	int i;

	fscanf (fin, "%d%d", &n, &s);

	if (n>30) return "N not in range";
	if (s>30) return "S not in range";

	for (i=0; i<n; i++) {
		if (fscanf (fin, "%lf", &L[i]) != 1) return "Not enough lengths";
		if (L[i]<=0 || L[i]>100) return "Bad lengths";
	}

	for (i=0; i<s; i++) {
		if (fscanf (fin, "%lf%lf", &A[i].x, &A[i].y) != 2) return "Not enough points in test";
		if (A[i].x<0.0-eps || A[i].x>10000.0+eps) return "Point not in range";
		if (A[i].y<0.0-eps || A[i].y>10000.0+eps) return "Point not in range";
	}

	if (fscanf (fin, "%lf%lf", &A[i].x, &A[i].y) > 0)
		return "Too many points in test";

	for (i=0; i<n; i++)
		if (fscanf (fans, "%lf%lf", &ans[i].x, &ans[i].y) != 2)
			return "@ Not enough points in competitor's out";

	if (fscanf (fans, "%lf%lf", &ans[i].x, &ans[i].y) > 0)
		return "@ Too many points in competitor's out";

	return "OK";
}

bool eq (double a, double b) { return fabs(a-b)<eps; }
double dist (point &a, point &b) { return sqrt( (b.x-a.x)*(b.x-a.x) + (b.y-a.y)*(b.y-a.y) ); }

double calc_ang (point p)
{
	int i;
	double min_ang, max_ang, ang;
	point vprev, v;

	min_ang = atan2 (p.y, p.x);
	max_ang = atan2 (p.y, p.x);
	
	vprev = point(0.0, 0.0);

	for (i=0; i<n; i++) {
		v.x = vprev.x + (ans[i].x - (i?ans[i-1].x:0));
		v.y = vprev.y + (ans[i].y - (i?ans[i-1].y:0));

		ang = atan2 (p.y-v.y, p.x-v.x);
		if (ang < min_ang) min_ang = ang;
		if (ang > max_ang) max_ang = ang;
		vprev = v;
	}

	return max_ang-min_ang;
}

char* check ()
{
	int i;
	double d, x, y;

	for (i=0; i<n; i++) {
		/*
		d = dist(i?ans[i-1]:point(0.0,0.0),ans[i]);
		if ( !eq(d,L[i]) ) {
			printf ("Length is %.8lf, but it must be %.8lf: diff=%.8lf\n", d, L[i], fabs(d-L[i]));
			return "@ Wrong Amino-length!";
		}
		*/

		x = ans[i].x - (i?ans[i-1].x:0.0);
		y = ans[i].y - (i?ans[i-1].y:0.0);

		if ( !eq(x, L[i]/d * x) ) {
			printf ("Current X is %.8lf, but it must be %.8lf: diff=%.8lf\n", x, L[i]/d * x, fabs(x - L[i]/d * x));
			return "@ Wrong Amino-length!";
		}

		if ( !eq(y, L[i]/d * y) ) {
			printf ("Current Y is %.8lf, but it must be %.8lf: diff=%.8lf\n", y, L[i]/d * y, fabs(y - L[i]/d * y));
			return "@ Wrong Amino-length!";
		}
	}

	double sum=0.0;

	for (i=0; i<s; i++)
		sum += calc_ang (A[i]);
	
	printf ("Sum of angles: %.4lf\n", sum);
	return "OK";
}

int main (int argc, char *argv[])
{
	if (argc<3) printf ("Not enough input parameters for testing\n");
	else {
		printf ("<%s> <%s>\n", argv[1], argv[2]);
		char *res = input (argv[1],argv[2]);
		printf ("input: %s\n", res);
		if ( strcmp(res,"OK") != 0 ) return 1;
		printf ("check: %s\n", check ());
	}

	return 0;
}